@@ -6,7 +6,7 @@
 #![allow(deprecated)]
 #![allow(non_camel_case_types)]
 
-mod macro_serde_string;
+mod macros;
 
 mod champion;
 pub use champion::*;
@@ -31,8 +31,8 @@ pub use queue::*;
 
 pub mod ranks;
 
-mod region;
-pub use region::*;
+mod route;
+pub use route::*;
 
 mod season;
 pub use season::*;
